---
title: "MCP4725"
linkTitle: "MCP4725"
weight: 4
description: >
  Microchip 4725 Digital-to-Analog Converter
---

## Registers

### EEPROM
If EEPROM is set, the saved voltage output will
be loaded from power-on.


### Output voltage
VOut = (Vcc * value) / 4096
The output is a range between 0 and Vcc with
steps of Vcc/4096.
In a 3.3v system, each step is 800 microvolts.


## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_MCP4725 version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_